==> authentik-2025.6.1-1-x86_64.pkg.tar.zst: opt/authentik/src/web/src/admin/providers/saml/SAMLProviderFormHelpers.ts <==
import { DEFAULT_CONFIG } from "@goauthentik/common/api/config";
import { DualSelectPair } from "@goauthentik/elements/ak-dual-select/types.js";

import { PropertymappingsApi, SAMLPropertyMapping } from "@goauthentik/api";

const mappingToSelect = (m: SAMLPropertyMapping) => [m.pk, m.name, m.name, m];

export async function propertyMappingsProvider(page = 1, search = "") {
    const propertyMappings = await new PropertymappingsApi(
        DEFAULT_CONFIG,
    ).propertymappingsProviderSamlList({
        ordering: "saml_name",
        pageSize: 20,
        search: search.trim(),
        page,
    });
    return {
        pagination: propertyMappings.pagination,
        options: propertyMappings.results.map(mappingToSelect),
    };
}

export function propertyMappingsSelector(instanceMappings?: string[]) {
    if (!instanceMappings) {
        return async (mappings: DualSelectPair<SAMLPropertyMapping>[]) =>
            mappings.filter(([_0, _1, _2, mapping]: DualSelectPair<SAMLPropertyMapping>) =>
                mapping?.managed?.startsWith("goauthentik.io/providers/saml"),
            );
    }

    return async () => {
        const pm = new PropertymappingsApi(DEFAULT_CONFIG);
        const mappings = await Promise.allSettled(
            instanceMappings.map((instanceId) =>
                pm.propertymappingsProviderSamlRetrieve({ pmUuid: instanceId }),
            ),
        );

        return mappings
            .filter((s) => s.status === "fulfilled")
            .map((s) => s.value)
            .map(mappingToSelect);
    };
}

==> authentik-2025.8.0-1-x86_64.pkg.tar.zst: opt/authentik/src/web/src/admin/providers/saml/SAMLProviderFormHelpers.ts <==
import { DEFAULT_CONFIG } from "#common/api/config";

import { DualSelectPair } from "#elements/ak-dual-select/types";

import { PropertymappingsApi, SAMLPropertyMapping } from "@goauthentik/api";

const mappingToSelect = (m: SAMLPropertyMapping) => [m.pk, m.name, m.name, m];

export async function propertyMappingsProvider(page = 1, search = "") {
    const propertyMappings = await new PropertymappingsApi(
        DEFAULT_CONFIG,
    ).propertymappingsProviderSamlList({
        ordering: "saml_name",
        pageSize: 20,
        search: search.trim(),
        page,
    });
    return {
        pagination: propertyMappings.pagination,
        options: propertyMappings.results.map(mappingToSelect),
    };
}

export function propertyMappingsSelector(instanceMappings?: string[]) {
    if (!instanceMappings) {
        return async (mappings: DualSelectPair<SAMLPropertyMapping>[]) =>
            mappings.filter(([_0, _1, _2, mapping]: DualSelectPair<SAMLPropertyMapping>) =>
                mapping?.managed?.startsWith("goauthentik.io/providers/saml"),
            );
    }

    return async () => {
        const pm = new PropertymappingsApi(DEFAULT_CONFIG);
        const mappings = await Promise.allSettled(
            instanceMappings.map((instanceId) =>
                pm.propertymappingsProviderSamlRetrieve({ pmUuid: instanceId }),
            ),
        );

        return mappings
            .filter((s) => s.status === "fulfilled")
            .map((s) => s.value)
            .map(mappingToSelect);
    };
}
